Struct amazon_sp_aplus_content::models::post_content_document_response::PostContentDocumentResponse
source · [−]pub struct PostContentDocumentResponse {
pub warnings: Option<Vec<Error>>,
pub content_reference_key: String,
}Fields
warnings: Option<Vec<Error>>A set of messages to the user, such as warnings or comments.
content_reference_key: StringA unique reference key for the A+ Content document. A content reference key cannot form a permalink and may change in the future. A content reference key is not guaranteed to match any A+ content identifier.
Implementations
sourceimpl PostContentDocumentResponse
impl PostContentDocumentResponse
pub fn new(content_reference_key: String) -> PostContentDocumentResponse